Booleano: Boolean Expressions Interpreter
=========================================

**Booleano** is an interpreter of `boolean expressions
<http://en.wikipedia.org/wiki/Boolean_expression>`_, a library to **define
and run filters** available as text (e.g., in a natural language) or in
`Python <http://python.org/>`_ code.

In order to handle text-based filters, Booleano ships with a fully-featured
parser whose grammar is `adaptive
<http://en.wikipedia.org/wiki/Adaptive_grammar>`_: Its properties
can be overridden using simple configuration directives.

On the other hand, the library exposes a pythonic API for filters written
in pure Python. These filters are particularly useful to build reusable
conditions from objects provided by a third party library.

Links
-----

* `Web site <http://code.gustavonarea.net/booleano/>`_.
* `Mailing list <http://groups.google.com/group/booleano>`_.
* `Bug reports <https://bugs.launchpad.net/booleano>`_.
